If your application accesses sensitive data with a WebView, you may want
to use the clearCache() method to delete any files stored locally.

Any URI received via an intent from outside a trust-boundary should be
validated before rendering it with WebView
